# Changelog

## [0.5.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.5.0a1) (2025-01-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.4.0...0.5.0a1)

**Merged pull requests:**

- feat:persona pipeline [\#648](https://github.com/OpenVoiceOS/ovos-core/pull/648) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
